@@ -477,7 +477,7 @@ draw_combobox_frame(DRAW_ARGS, const GtkWidgetPath* path, GtkStateFlags state, G
 		TQPainter p(&pd);
 
 		TQStringList objectTypes;
-		objectTypes.append(TQCOMBOBOX_OBJECT_NAME_STRING);
+		objectTypes.append("TQComboBox");
 		TQPalette objectPalette = tqApp->palette(objectTypes);
 
 		TQStyleControlElementData ceData;
@@ -520,7 +520,7 @@ draw_progressbar_frame(DRAW_ARGS, const GtkWidgetPath* path, GtkStateFlags state
 		TQPainter p(&pd);
 
 		TQStringList objectTypes;
-		objectTypes.append(TQPROGRESSBAR_OBJECT_NAME_STRING);
+		objectTypes.append("TQProgressBar");
 		TQPalette objectPalette = tqApp->palette(objectTypes);
 	
 		TQStyleControlElementData ceData;
@@ -610,7 +610,7 @@ draw_slider_frame(DRAW_ARGS, const GtkWidgetPath* path, GtkStateFlags state, Gtk
 		GtkScale* scaleWidget = GTK_SCALE(widget);
 
 		TQStringList objectTypes;
-		objectTypes.append(TQSLIDER_OBJECT_NAME_STRING);
+		objectTypes.append("TQSlider");
 		TQPalette objectPalette = tqApp->palette(objectTypes);
 
 		TQStyleControlElementData ceData;
@@ -669,7 +669,7 @@ draw_scrollbar_frame(DRAW_ARGS, const GtkWidgetPath* path, GtkStateFlags state,
 		GtkScrollbar* scrollbarWidget = GTK_SCROLLBAR(widget);
 
 		TQStringList objectTypes;
-		objectTypes.append(TQSLIDER_OBJECT_NAME_STRING);
+		objectTypes.append("TQSlider");
 		TQPalette objectPalette = tqApp->palette(objectTypes);
 
 		TQStyleControlElementData ceData;
@@ -812,7 +812,7 @@ draw_scrollbar_frame(DRAW_ARGS, const GtkWidgetPath* path, GtkStateFlags state,
 static void
 draw_checkbox(DRAW_ARGS, const GtkWidgetPath* path, GtkStateFlags state, GtkWidget* widget, TQt3WidgetType tqt3WidgetType) {
 	TQStringList objectTypes;
-	objectTypes.append(TQCHECKBOX_OBJECT_NAME_STRING);
+	objectTypes.append("TQCheckBox");
 	TQPalette objectPalette = tqApp->palette(objectTypes);
 
 	TQRect boundingRect(0, 0, width, height);
@@ -835,7 +835,7 @@ draw_checkbox(DRAW_ARGS, const GtkWidgetPath* path, GtkStateFlags state, GtkWidg
 static void
 draw_radiobutton(DRAW_ARGS, const GtkWidgetPath* path, GtkStateFlags state, GtkWidget* widget, TQt3WidgetType tqt3WidgetType) {
 	TQStringList objectTypes;
-	objectTypes.append(TQCHECKBOX_OBJECT_NAME_STRING);
+	objectTypes.append("TQCheckBox");
 	TQPalette objectPalette = tqApp->palette(objectTypes);
 
 	TQRect boundingRect(0, 0, width, height);
@@ -858,7 +858,7 @@ draw_radiobutton(DRAW_ARGS, const GtkWidgetPath* path, GtkStateFlags state, GtkW
 static void
 draw_pushbutton(DRAW_ARGS, const GtkWidgetPath* path, GtkStateFlags state, GtkWidget* widget, TQt3WidgetType tqt3WidgetType) {
 	TQStringList objectTypes;
-	objectTypes.append(TQCHECKBOX_OBJECT_NAME_STRING);
+	objectTypes.append("TQCheckBox");
 	TQPalette objectPalette = tqApp->palette(objectTypes);
 
 	TQRect boundingRect(0, 0, width, height);
@@ -886,7 +886,7 @@ draw_toolbar_button(DRAW_ARGS, const GtkWidgetPath* path, GtkStateFlags state, G
 	bool mousedown = (state & GTK_STATE_FLAG_ACTIVE) != 0;
 
 	TQStringList objectTypes;
-	objectTypes.append(TQTOOLBUTTON_OBJECT_NAME_STRING);
+	objectTypes.append("TQToolButton");
 	TQPalette objectPalette = tqApp->palette(objectTypes);
 
 	TQStyleControlElementData ceData;
@@ -904,7 +904,7 @@ draw_toolbar_button(DRAW_ARGS, const GtkWidgetPath* path, GtkStateFlags state, G
 	GtkWidget* parent = (widget)?Gtk::gtk_widget_find_parent(widget, GTK_TYPE_TOOLBAR):0L;
 	if (parent) {
 		TQStringList parentObjectTypes;
-		parentObjectTypes.append(TQTOOLBAR_OBJECT_NAME_STRING);
+		parentObjectTypes.append("TQToolBar");
 		TQPalette parentObjectPalette = tqApp->palette(parentObjectTypes);
 		const GtkAllocation allocation = Gtk::gtk_widget_get_allocation(parent);
 
@@ -983,7 +983,7 @@ tdegtk_draw_activity (DRAW_ARGS)
 	if (gtk_widget_path_is_type(path, GTK_TYPE_PROGRESS_BAR)) {
 #if 0
 		TQStringList objectTypes;
-		objectTypes.append(TQPROGRESSBAR_OBJECT_NAME_STRING);
+		objectTypes.append("TQProgressBar");
 		TQPalette objectPalette = tqApp->palette(objectTypes);
 
 		TQStyleControlElementData ceData;
@@ -1062,7 +1062,7 @@ tdegtk_draw_arrow (GtkThemingEngine *engine,
 	if (gtk_theming_engine_has_class(engine, GTK_STYLE_CLASS_SCROLLBAR)) {
 #ifdef DRAW_SCROLLBAR_PIECES_INSTEAD_OF_ENTIRE_BAR
 		TQStringList objectTypes;
-		objectTypes.append(TQSCROLLBAR_OBJECT_NAME_STRING);
+		objectTypes.append("TQScrollBar");
 		TQPalette objectPalette = tqApp->palette(objectTypes);
 
 		GtkRange* rangeWidget = GTK_RANGE(widget);
@@ -1162,12 +1162,12 @@ tdegtk_draw_arrow (GtkThemingEngine *engine,
 
 		TQt3WidgetType tqt3WidgetType = TQT3WT_NONE;
 		TQStringList objectTypes;
-		objectTypes.append(TQWIDGET_OBJECT_NAME_STRING);
+		objectTypes.append("TQWidget");
 		if ((gtk_theming_engine_has_class(engine, GTK_STYLE_CLASS_MENU)) || (gtk_theming_engine_has_class(engine, GTK_STYLE_CLASS_MENUITEM))) {
 			GtkWidget* parent(widget?gtk_widget_get_parent(widget):0L);
 			if (!GTK_IS_MENU_BAR(parent)) {
 				objectTypes.clear();
-				objectTypes.append(TQPOPUPMENU_OBJECT_NAME_STRING);
+				objectTypes.append("TQPopupMenu");
 				tqt3WidgetType = TQT3WT_TQMenuItem;
 			}
 		}
@@ -1208,7 +1208,7 @@ tdegtk_draw_cell_background (DRAW_ARGS,
 
 	if (gtk_widget_path_is_type(path, GTK_TYPE_TREE_VIEW)) {
 		TQStringList objectTypes;
-		objectTypes.append(TQLISTVIEW_OBJECT_NAME_STRING);
+		objectTypes.append("TQListView");
 		TQPalette objectPalette = tqApp->palette(objectTypes);
 
 		TQStyleControlElementData ceData;
@@ -1262,7 +1262,7 @@ tdegtk_draw_cell_frame (DRAW_ARGS,
 	if (gtk_widget_path_is_type(path, GTK_TYPE_TREE_VIEW)) {
 #if 0
 		TQStringList objectTypes;
-		objectTypes.append(TQLISTVIEW_OBJECT_NAME_STRING);
+		objectTypes.append("TQListView");
 		TQPalette objectPalette = tqApp->palette(objectTypes);
 
 		TQStyleControlElementData ceData;
@@ -1355,7 +1355,7 @@ tdegtk_draw_common_background (DRAW_ARGS)
 	if (gtk_theming_engine_has_class(engine, GTK_STYLE_CLASS_SCROLLBAR)) {
 #ifdef DRAW_SCROLLBAR_PIECES_INSTEAD_OF_ENTIRE_BAR
 		TQStringList objectTypes;
-		objectTypes.append(TQSCROLLBAR_OBJECT_NAME_STRING);
+		objectTypes.append("TQScrollBar");
 		TQPalette objectPalette = tqApp->palette(objectTypes);
 
 		GtkRange* rangeWidget = GTK_RANGE(widget);
@@ -1378,7 +1378,7 @@ tdegtk_draw_common_background (DRAW_ARGS)
 	else if (gtk_widget_path_is_type(path, GTK_TYPE_SCROLLED_WINDOW)) {
 		if ((x == 0) && (y == 0)) {
 			TQStringList objectTypes;
-			objectTypes.append(TQFRAME_OBJECT_NAME_STRING);
+			objectTypes.append("TQFrame");
 			TQPalette objectPalette = tqApp->palette(objectTypes);
 	
 			int groupBoxLineWidth = 1;
@@ -1413,7 +1413,7 @@ tdegtk_draw_common_background (DRAW_ARGS)
 		|| (gtk_theming_engine_has_class(engine, GTK_STYLE_CLASS_COMBOBOX_ENTRY))
 		) {
 		TQStringList objectTypes;
-		objectTypes.append(TQLINEEDIT_OBJECT_NAME_STRING);
+		objectTypes.append("TQLineEdit");
 		TQPalette objectPalette = tqApp->palette(objectTypes);
 
 		// Draw background
@@ -1426,7 +1426,7 @@ tdegtk_draw_common_background (DRAW_ARGS)
 		bool mousedown = (state & GTK_STATE_FLAG_ACTIVE) != 0;
 
 		TQStringList objectTypes;
-		objectTypes.append(TQCOMBOBOX_OBJECT_NAME_STRING);
+		objectTypes.append("TQComboBox");
 		TQPalette objectPalette = tqApp->palette(objectTypes);
 
 		TQStyleControlElementData ceData;
@@ -1448,7 +1448,7 @@ tdegtk_draw_common_background (DRAW_ARGS)
 	else if (gtk_widget_path_is_type(path, GTK_TYPE_BUTTON)) {
 #if 0
 		TQStringList objectTypes;
-		objectTypes.append(TQBUTTON_OBJECT_NAME_STRING);
+		objectTypes.append("TQButton");
 		TQPalette objectPalette = tqApp->palette(objectTypes);
 
 		if (Gtk::gtk_widget_path_has_type(path, GTK_TYPE_TOOLBAR)) {
@@ -1471,7 +1471,7 @@ tdegtk_draw_common_background (DRAW_ARGS)
 
 	else if (gtk_theming_engine_has_class(engine, GTK_STYLE_CLASS_TOOLBAR)) {
 		TQStringList objectTypes;
-		objectTypes.append(TQTOOLBAR_OBJECT_NAME_STRING);
+		objectTypes.append("TQToolBar");
 		TQPalette objectPalette = tqApp->palette(objectTypes);
 
 		// Draw background
@@ -1481,7 +1481,7 @@ tdegtk_draw_common_background (DRAW_ARGS)
 
 	else if (gtk_theming_engine_has_class(engine, GTK_STYLE_CLASS_MENUBAR)) {
 		TQStringList objectTypes;
-		objectTypes.append(TQMENUBAR_OBJECT_NAME_STRING);
+		objectTypes.append("TQMenuBar");
 		TQPalette objectPalette = tqApp->palette(objectTypes);
 
 		// Draw background
@@ -1491,7 +1491,7 @@ tdegtk_draw_common_background (DRAW_ARGS)
 
 	else if (gtk_theming_engine_has_class(engine, GTK_STYLE_CLASS_TOOLTIP)) {
 		TQStringList objectTypes;
-		objectTypes.append(TQTIPLABEL_OBJECT_NAME_STRING);
+		objectTypes.append("TQTipLabel");
 		TQPalette objectPalette = tqApp->palette(objectTypes);
 
 		// Draw background
@@ -1519,7 +1519,7 @@ tdegtk_draw_common_background (DRAW_ARGS)
 // 			bool selectedTab = (tabIndex==currentPage);
 
 			TQStringList objectTypes;
-			objectTypes.append(TQPOPUPMENU_OBJECT_NAME_STRING);
+			objectTypes.append("TQPopupMenu");
 			TQPalette objectPalette = tqApp->palette(objectTypes);
 
 			bool pressed = false;
@@ -1550,7 +1550,7 @@ tdegtk_draw_common_background (DRAW_ARGS)
 
 	else if (gtk_widget_path_is_type(path, GTK_TYPE_NOTEBOOK)) {
 		TQStringList objectTypes;
-		objectTypes.append(TQTABWIDGET_OBJECT_NAME_STRING);
+		objectTypes.append("TQTabWidget");
 		TQPalette objectPalette = tqApp->palette(objectTypes);
 
 		// Draw background
@@ -1564,7 +1564,7 @@ tdegtk_draw_common_background (DRAW_ARGS)
 
 	else if (gtk_widget_path_is_type(path, GTK_TYPE_HANDLE_BOX)) {
 		TQStringList objectTypes;
-		objectTypes.append(TQDOCKWINDOWHANDLE_OBJECT_NAME_STRING);
+		objectTypes.append("TQDockWindowHandle");
 		TQPalette objectPalette = tqApp->palette(objectTypes);
 
 		// Draw background
@@ -1574,7 +1574,7 @@ tdegtk_draw_common_background (DRAW_ARGS)
 
 	else if (gtk_theming_engine_has_class(engine, GTK_STYLE_CLASS_CELL)) {
 		TQStringList objectTypes;
-		objectTypes.append(TQLISTVIEW_OBJECT_NAME_STRING);
+		objectTypes.append("TQListView");
 		TQPalette objectPalette = tqApp->palette(objectTypes);
 
 		TQStyleControlElementData ceData;
@@ -1602,7 +1602,7 @@ tdegtk_draw_common_background (DRAW_ARGS)
 	else if (gtk_widget_path_is_type(path, GTK_TYPE_LABEL)) {
 		if (gtk_theming_engine_has_class(engine, GTK_STYLE_CLASS_FRAME)) {
 			TQStringList objectTypes;
-			objectTypes.append(TQFRAME_OBJECT_NAME_STRING);
+			objectTypes.append("TQFrame");
 			TQPalette objectPalette = tqApp->palette(objectTypes);
 	
 			// Draw background
@@ -1620,7 +1620,7 @@ tdegtk_draw_common_background (DRAW_ARGS)
 
 	else if (gtk_widget_path_is_type(path, GTK_TYPE_SWITCH)) {
 		TQStringList objectTypes;
-		objectTypes.append(TQSCROLLBAR_OBJECT_NAME_STRING);
+		objectTypes.append("TQScrollBar");
 		TQPalette objectPalette = tqApp->palette(objectTypes);
 
 		TQStyleControlElementData ceData;
@@ -1637,7 +1637,7 @@ tdegtk_draw_common_background (DRAW_ARGS)
 #ifdef GTK_TYPE_LEVEL_BAR
 	else if (gtk_widget_path_is_type(path, GTK_TYPE_LEVEL_BAR)) {
 		TQStringList objectTypes;
-		objectTypes.append(TQPROGRESSBAR_OBJECT_NAME_STRING);
+		objectTypes.append("TQProgressBar");
 		TQPalette objectPalette = tqApp->palette(objectTypes);
 
 		if (gtk_theming_engine_has_class(engine, "fill-block")) {
@@ -1675,7 +1675,7 @@ tdegtk_draw_common_background (DRAW_ARGS)
 
 	else if (widgetThemingEnginePath.endsWith("GtkTreeView.view")) {
 		TQStringList objectTypes;
-		objectTypes.append(TQLISTVIEW_OBJECT_NAME_STRING);
+		objectTypes.append("TQListView");
 		TQPalette objectPalette = tqApp->palette(objectTypes);
 
 		// Draw background
@@ -1691,7 +1691,7 @@ tdegtk_draw_common_background (DRAW_ARGS)
 		|| (gtk_widget_path_is_type(path, GTK_TYPE_FRAME))
 		) {
 		TQStringList objectTypes;
-		objectTypes.append(TQWIDGET_OBJECT_NAME_STRING);
+		objectTypes.append("TQWidget");
 		TQPalette objectPalette = tqApp->palette(objectTypes);
 
 		// Draw background
@@ -1736,7 +1736,7 @@ tdegtk_draw_common_frame (DRAW_ARGS)
 		}
 		else {
 			TQStringList objectTypes;
-			objectTypes.append(TQSCROLLBAR_OBJECT_NAME_STRING);
+			objectTypes.append("TQScrollBar");
 			TQPalette objectPalette = tqApp->palette(objectTypes);
 
 			GtkRange* rangeWidget = GTK_RANGE(widget);
@@ -1791,7 +1791,7 @@ tdegtk_draw_common_frame (DRAW_ARGS)
 			GtkWidget* parent(widget?gtk_widget_get_parent(widget):0L);
 			if (GTK_IS_MENU_BAR(parent)) {
 				TQStringList objectTypes;
-				objectTypes.append(TQMENUBAR_OBJECT_NAME_STRING);
+				objectTypes.append("TQMenuBar");
 				TQPalette objectPalette = tqApp->palette(objectTypes);
 		
 				TQStyleControlElementData ceData;
@@ -1820,7 +1820,7 @@ tdegtk_draw_common_frame (DRAW_ARGS)
 		// Certain styles (highcolor) paint over the color swatches if this is enabled, rendering the picker useless
 		else if (widgetPath.endsWith(".GtkColorSwatch")) {
 			TQStringList objectTypes;
-			objectTypes.append(TQLINEEDIT_OBJECT_NAME_STRING);
+			objectTypes.append("TQLineEdit");
 			TQPalette objectPalette = tqApp->palette(objectTypes);
 	
 			// Draw frame
@@ -1835,7 +1835,7 @@ tdegtk_draw_common_frame (DRAW_ARGS)
 
 		else if (gtk_theming_engine_has_class(engine, GTK_STYLE_CLASS_ENTRY)) {
 			TQStringList objectTypes;
-			objectTypes.append(TQLINEEDIT_OBJECT_NAME_STRING);
+			objectTypes.append("TQLineEdit");
 			TQPalette objectPalette = tqApp->palette(objectTypes);
 	
 			// Draw frame
@@ -1866,7 +1866,7 @@ tdegtk_draw_common_frame (DRAW_ARGS)
 
 		else if (gtk_theming_engine_has_class(engine, GTK_STYLE_CLASS_MENU)) {
 			TQStringList objectTypes;
-			objectTypes.append(TQPOPUPMENU_OBJECT_NAME_STRING);
+			objectTypes.append("TQPopupMenu");
 			TQPalette objectPalette = tqApp->palette(objectTypes);
 
 			TQStyleControlElementData ceData;
@@ -1881,7 +1881,7 @@ tdegtk_draw_common_frame (DRAW_ARGS)
 
 		else if (gtk_theming_engine_has_class(engine, GTK_STYLE_CLASS_TOOLTIP)) {
 			TQStringList objectTypes;
-			objectTypes.append(TQTOOLTIP_OBJECT_NAME_STRING);
+			objectTypes.append("TQToolTip");
 			TQPalette objectPalette = tqApp->palette(objectTypes);
 	
 			int groupBoxLineWidth = 1;
@@ -1921,7 +1921,7 @@ tdegtk_draw_common_frame (DRAW_ARGS)
 			TQPainter p2(&pd2);
 
 			TQStringList objectTypes;
-			objectTypes.append(TQPROGRESSBAR_OBJECT_NAME_STRING);
+			objectTypes.append("TQProgressBar");
 			TQPalette objectPalette = tqApp->palette(objectTypes);
 
 			TQStyleControlElementData ceData;
@@ -2059,7 +2059,7 @@ tdegtk_draw_extension (DRAW_ARGS,
 		bool selectedTab = (tabIndex==currentPage);
 
 		TQStringList objectTypes;
-		objectTypes.append(TQTABBAR_OBJECT_NAME_STRING);
+		objectTypes.append("TQTabBar");
 		TQPalette objectPalette = tqApp->palette(objectTypes);
 
 		TQStyleControlElementData ceData;
@@ -2072,7 +2072,7 @@ tdegtk_draw_extension (DRAW_ARGS,
 		TQStyleOption tabOpt(&tqt3Tab, (prelight)?&tqt3Tab:(TQTab*)NULL);
 
 		elementFlags = elementFlags | TQStyle::CEF_HasParentWidget;
-		ceData.parentWidgetData.widgetObjectTypes.append(TQTABBAR_OBJECT_NAME_STRING);
+		ceData.parentWidgetData.widgetObjectTypes.append("TQTabBar");
 
 		int tab_overlap = tqApp->style().pixelMetric(TQStyle::PM_TabBarTabOverlap);
 		int tab_to_frame_gap_height = 2;
@@ -2191,16 +2191,16 @@ tdegtk_draw_focus (DRAW_ARGS)
 			|| (gtk_theming_engine_has_class(engine, GTK_STYLE_CLASS_ENTRY))
 			|| (gtk_theming_engine_has_class(engine, GTK_STYLE_CLASS_COMBOBOX_ENTRY))
 			) {
-			objectTypes.append(TQLINEEDIT_OBJECT_NAME_STRING);
+			objectTypes.append("TQLineEdit");
 		}
 		else if (gtk_widget_path_is_type(path, GTK_TYPE_TREE_VIEW)) {
-			objectTypes.append(TQLISTVIEW_OBJECT_NAME_STRING);
+			objectTypes.append("TQListView");
 		}
 		else if (gtk_widget_path_is_type(path, GTK_TYPE_BUTTON)) {
-			objectTypes.append(TQPUSHBUTTON_OBJECT_NAME_STRING);
+			objectTypes.append("TQPushButton");
 		}
 		else {
-			objectTypes.append(TQWIDGET_OBJECT_NAME_STRING);
+			objectTypes.append("TQWidget");
 		}
 
 		TQPalette objectPalette = tqApp->palette(objectTypes);
@@ -2219,7 +2219,7 @@ tdegtk_draw_focus (DRAW_ARGS)
 
 		if (gtk_widget_path_is_type(path, GTK_TYPE_BUTTON)) {
 			TQStringList objectTypes;
-			objectTypes.append(TQBUTTON_OBJECT_NAME_STRING);
+			objectTypes.append("TQButton");
 			ceData.widgetObjectTypes = objectTypes;
 			ceData.rect = boundingRect;
 
@@ -2272,7 +2272,7 @@ tdegtk_draw_frame_gap (DRAW_ARGS,
 		GtkShadowType gtkShadowType = gtk_frame_get_shadow_type(frame);
 
 		TQStringList objectTypes;
-		objectTypes.append(TQGROUPBOX_OBJECT_NAME_STRING);
+		objectTypes.append("TQGroupBox");
 		TQPalette objectPalette = tqApp->palette(objectTypes);
 
 		int groupBoxLineWidth = 1;
@@ -2343,7 +2343,7 @@ tdegtk_draw_grip (DRAW_ARGS)
 	widget = m_widgetLookup.find(cr, path);
 
 	TQStringList objectTypes;
-	objectTypes.append(TQSTATUSBAR_OBJECT_NAME_STRING);
+	objectTypes.append("TQStatusBar");
 	TQPalette objectPalette = tqApp->palette(objectTypes);
 
 	// Draw background
@@ -2378,7 +2378,7 @@ tdegtk_draw_handle (DRAW_ARGS)
 
 	if (gtk_widget_path_is_type(path, GTK_TYPE_HANDLE_BOX)) {
 		TQStringList objectTypes;
-		objectTypes.append(TQDOCKWINDOWHANDLE_OBJECT_NAME_STRING);
+		objectTypes.append("TQDockWindowHandle");
 		TQPalette objectPalette = tqApp->palette(objectTypes);
 	
 		// Draw handle
@@ -2387,7 +2387,7 @@ tdegtk_draw_handle (DRAW_ARGS)
 
 	else if (gtk_widget_path_is_type(path, GTK_TYPE_PANED)) {
 		TQStringList objectTypes;
-		objectTypes.append(TQSPLITTER_OBJECT_NAME_STRING);
+		objectTypes.append("TQSplitter");
 		TQPalette objectPalette = tqApp->palette(objectTypes);
 	
 		// Draw handle
@@ -2453,7 +2453,7 @@ tdegtk_draw_notebook (DRAW_ARGS,
 
 	if (gtk_theming_engine_has_class(engine, GTK_STYLE_CLASS_NOTEBOOK)) {
 		TQStringList objectTypes;
-		objectTypes.append(TQTABWIDGET_OBJECT_NAME_STRING);
+		objectTypes.append("TQTabWidget");
 		TQPalette objectPalette = tqApp->palette(objectTypes);
 	
 		// Draw background
@@ -2498,7 +2498,7 @@ tdegtk_draw_radio (DRAW_ARGS)
 		int maxIconWidth = IconSize(TDEIcon::Small) + 4;
 
 		TQStringList objectTypes;
-		objectTypes.append(TQPOPUPMENU_OBJECT_NAME_STRING);
+		objectTypes.append("TQPopupMenu");
 		TQPalette objectPalette = tqApp->palette(objectTypes);
 
 		TQStyleControlElementData ceData;
@@ -2541,7 +2541,7 @@ tdegtk_draw_separator (DRAW_ARGS)
 
 	if (gtk_widget_path_is_type(path, GTK_TYPE_SEPARATOR_MENU_ITEM)) {
 		TQStringList objectTypes;
-		objectTypes.append(TQPOPUPMENU_OBJECT_NAME_STRING);
+		objectTypes.append("TQPopupMenu");
 		TQPalette objectPalette = tqApp->palette(objectTypes);
 
 		bool pressed = false;
@@ -2631,7 +2631,7 @@ tdegtk_draw_slider (DRAW_ARGS,
 	if (gtk_theming_engine_has_class(engine, GTK_STYLE_CLASS_SCROLLBAR)) {
 #ifdef DRAW_SCROLLBAR_PIECES_INSTEAD_OF_ENTIRE_BAR
 		TQStringList objectTypes;
-		objectTypes.append(TQSCROLLBAR_OBJECT_NAME_STRING);
+		objectTypes.append("TQScrollBar");
 		TQPalette objectPalette = tqApp->palette(objectTypes);
 
 		GtkRange* rangeWidget = GTK_RANGE(widget);
@@ -2666,7 +2666,7 @@ tdegtk_draw_slider (DRAW_ARGS,
 
 	else if (gtk_widget_path_is_type(path, GTK_TYPE_SWITCH)) {
 		TQStringList objectTypes;
-		objectTypes.append(TQSCROLLBAR_OBJECT_NAME_STRING);
+		objectTypes.append("TQScrollBar");
 		TQPalette objectPalette = tqApp->palette(objectTypes);
 
 		TQStyleControlElementData ceData;
